from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()
setup(
name="auto_importer_py",
version="0.1.0",
description="Automatically import common Python libraries into the importer module namespace",
long_description=long_description,
long_description_content_type="text/markdown",
author="your-name",
author_email="your-email@example.com",
url="https://github.com/yourname/auto_import",
packages=find_packages(),
python_requires=">=3.8",
classifiers=[
"Programming Language :: Python :: 3",
"License :: OSI Approved :: MIT License",
"Operating System :: OS Independent",
],
license="MIT",
)
